netapp_ontap.models.firmware_sp_bmc API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.firmware_sp_bmc`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FirmwareSpBmcSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FirmwareSpBmc object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `autoupdte GET`

    The autoupdte field of the firmware_sp_bmc.

    Example: false

  `end_time GET`

    The end_time field of the firmware_sp_bmc.

    Example: 2020-05-17T20:00:00.000+0000

  `fw_type GET`

    The fw_type field of the firmware_sp_bmc.

    Valid choices:

    - SP
    - BMC
  `image GET`

    The image field of the firmware_sp_bmc.

    Valid choices:

    - primary
    - backup
  `in_progress GET`

    The in_progress field of the firmware_sp_bmc.

  `is_current GET`

    The is_current field of the firmware_sp_bmc.

    Example: true

  `last_update_state GET`

    The last_update_state field of the firmware_sp_bmc.

    Valid choices:

    - passed
    - failed
  `percent_done GET`

    The percent_done field of the firmware_sp_bmc.

    Example: 100

  `running_version GET`

    The running_version field of the firmware_sp_bmc.

    Example: 1.2.3.4

  `start_time GET`

    The start_time field of the firmware_sp_bmc.

    Example: 2020-05-17T20:00:00.000+0000

  `state GET`

    The state field of the firmware_sp_bmc.

    Valid choices:

    - installed
    - corrupt
    - updating
    - autoupdating
    - none